@@ -14,10 +14,10 @@ struct MASBuildToolPlugin: BuildToolPlugin {
 		[
 			.prebuildCommand(
 				displayName: "Prebuild mas",
-				executable: context.package.directoryURL.appendingPathComponent("Scripts/prebuild", isDirectory: false),
-				arguments: [context.pluginWorkDirectoryURL.path],
+				executable: context.package.directoryURL.appending(path: "Scripts/prebuild", directoryHint: .notDirectory),
+				arguments: [context.pluginWorkDirectoryURL.path(percentEncoded: false)],
 				environment: ProcessInfo.processInfo.environment,
-				outputFilesDirectory: context.pluginWorkDirectoryURL
+				outputFilesDirectory: context.pluginWorkDirectoryURL,
 			),
 		]
 	}
