@@ -7,6 +7,7 @@
 
 private import ArgumentParser
 private import Darwin
+private import OrderedCollections
 private import StoreFoundation
 
 enum AppStoreAction: Sendable {
@@ -14,23 +15,51 @@ enum AppStoreAction: Sendable {
 	case install
 	case update
 
+	var performed: String {
+		switch self {
+		case .get:
+			"got"
+		case .install:
+			"installed"
+		case .update:
+			"updated"
+		}
+	}
+
+	var performing: String {
+		switch self {
+		case .get:
+			"getting"
+		case .install:
+			"installing"
+		case .update:
+			"updating"
+		}
+	}
+
+	func apps(
+		withAppIDs appIDs: [AppID],
+		force: Bool,
+		installedApps: [InstalledApp],
+		lookupAppFromAppID: (AppID) async throws -> CatalogApp,
+	) async throws {
+		try await apps(
+			withADAMIDs: await appIDs.lookupCatalogApps(lookupAppFromAppID: lookupAppFromAppID).map(\.adamID),
+			force: force,
+			installedApps: installedApps,
+		)
+	}
+
 	func apps(withADAMIDs adamIDs: [ADAMID], force: Bool, installedApps: [InstalledApp]) async throws {
 		try await apps(
 			withADAMIDs: adamIDs.filter { adamID in
 				if !force, let installedApp = installedApps.first(where: { $0.adamID == adamID }) {
-					MAS.printer.warning(
-						self == .get ? "Already gotten: " : "Already installed: ",
-						installedApp.name,
-						" (",
-						adamID,
-						")",
-						separator: ""
-					)
+					MAS.printer.warning("Already ", performed, " ", installedApp.name, " (", adamID, ")", separator: "")
 					return false
 				}
 
 				return true
-			}
+			},
 		)
 	}
 
@@ -38,6 +67,8 @@ enum AppStoreAction: Sendable {
 		guard !adamIDs.isEmpty else {
 			return
 		}
+
+		let adamIDs = OrderedSet(adamIDs)
 		guard getuid() == 0 else {
 			try sudo(MAS._commandName, args: [String(describing: self), "--force"] + adamIDs.map(String.init(describing:)))
 			return
