@@ -13,29 +13,32 @@ extension MAS {
 	/// Outputs mas config & related system info.
 	struct Config: ParsableCommand {
 		static let configuration = CommandConfiguration(
-			abstract: "Output mas config & related system info"
+			abstract: "Output mas config & related system info",
 		)
 
 		func run() {
 			printer.info(
 				"""
-				mas ▁▁▁▁ \(MAS.version)
+				mas ▁▁▁▁ \(version)
 				slice ▁▁ \(runningSliceArchitecture)
 				slices ▁ \(supportedSliceArchitectures.joined(separator: " "))
-				dist ▁▁▁ \(MAS.distribution)
-				origin ▁ \(MAS.gitOrigin)
-				rev ▁▁▁▁ \(MAS.gitRevision)
-				swift ▁▁ \(MAS.swiftVersion)
-				driver ▁ \(MAS.swiftDriverVersion)
+				dist ▁▁▁ \(distribution)
+				origin ▁ \(gitOrigin)
+				rev ▁▁▁▁ \(gitRevision)
+				swift ▁▁ \(swiftVersion)
+				driver ▁ \(swiftDriverVersion)
 				store ▁▁ \(appStoreRegion)
 				region ▁ \(macRegion)
 				macos ▁▁ \(
-					ProcessInfo.processInfo.operatingSystemVersionString.dropFirst(8).replacingOccurrences(of: "Build ", with: "")
+					ProcessInfo.processInfo
+					.operatingSystemVersionString // swiftformat:disable:this indent
+					.dropFirst(8) // swiftformat:disable:this indent
+					.replacing("Build ", with: "", maxReplacements: 1) // swiftformat:disable:this indent
 				)
 				mac ▁▁▁▁ \(configStringValue("hw.product"))
 				cpu ▁▁▁▁ \(configStringValue("machdep.cpu.brand_string"))
 				arch ▁▁▁ \(configStringValue("hw.machine"))
-				"""
+				""",
 			)
 		}
 	}
@@ -43,9 +46,13 @@ extension MAS {
 
 private var runningSliceArchitecture: String {
 	var info = utsname()
-	return uname(&info) == 0
+	return unsafe uname(&info) == 0
 	? withUnsafePointer(to: &info.machine) { pointer in // swiftformat:disable indent
-		pointer.withMemoryRebound(to: CChar.self, capacity: MemoryLayout.size(ofValue: pointer), String.init(cString:))
+		unsafe pointer.withMemoryRebound(
+			to: CChar.self,
+			capacity: unsafe MemoryLayout.size(ofValue: unsafe pointer),
+			unsafe String.init(cString:),
+		)
 	}
 	: unknown
 } // swiftformat:enable indent
@@ -58,7 +65,7 @@ private var supportedSliceArchitectures: [String] {
 			}
 
 			return switch arch {
-			case 0x100000c:
+			case NSBundleExecutableArchitectureARM64:
 				"arm64"
 			case NSBundleExecutableArchitectureI386:
 				"i386"
@@ -78,18 +85,18 @@ private var supportedSliceArchitectures: [String] {
 
 private func configStringValue(_ name: String) -> String {
 	var size = 0
-	guard sysctlbyname(name, nil, &size, nil, 0) == 0 else {
-		perror(sysCtlByName)
+	guard unsafe sysctlbyname(name, nil, &size, nil, 0) == 0 else {
+		unsafe perror(sysCtlByName)
 		return unknown
 	}
 
 	var buffer = [CChar](repeating: 0, count: size)
-	guard sysctlbyname(name, &buffer, &size, nil, 0) == 0 else {
-		perror(sysCtlByName)
+	guard unsafe sysctlbyname(name, &buffer, &size, nil, 0) == 0 else {
+		unsafe perror(sysCtlByName)
 		return unknown
 	}
 
-	return String(cString: &buffer)
+	return unsafe String(cString: &buffer)
 }
 
 private let unknown = "unknown"
