@@ -16,18 +16,20 @@ extension MAS {
 	/// https://performance-partners.apple.com/search-api
 	struct Home: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Open App Store app pages in the default web browser"
+			abstract: "Open App Store app pages in the default web browser",
 		)
 
 		@OptionGroup
 		private var requiredAppIDsOptionGroup: RequiredAppIDsOptionGroup
 
 		func run() async {
-			await run(appCatalog: ITunesSearchAppCatalog())
+			await run(lookupAppFromAppID: lookup(appID:))
 		}
 
-		private func run(appCatalog: some AppCatalog) async {
-			await run(catalogApps: await requiredAppIDsOptionGroup.appIDs.lookupCatalogApps(from: appCatalog))
+		private func run(lookupAppFromAppID: (AppID) async throws -> CatalogApp) async {
+			await run(
+				catalogApps: await requiredAppIDsOptionGroup.appIDs.lookupCatalogApps(lookupAppFromAppID: lookupAppFromAppID),
+			)
 		}
 
 		func run(catalogApps: [CatalogApp]) async { // swiftformat:disable:this organizeDeclarations
