@@ -12,7 +12,7 @@ extension MAS {
 	/// Lists all apps installed from the App Store.
 	struct List: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "List all apps installed from the App Store"
+			abstract: "List all apps installed from the App Store",
 		)
 
 		@OptionGroup
@@ -23,7 +23,7 @@ extension MAS {
 		}
 
 		func run(installedApps: [InstalledApp]) {
-			let installedApps = installedApps.filter(by: optionalAppIDsOptionGroup)
+			let installedApps = installedApps.filter(for: optionalAppIDsOptionGroup.appIDs)
 			guard
 				let maxADAMIDLength = installedApps.map({ String(describing: $0.adamID).count }).max(),
 				let maxNameLength = installedApps.map(\.name.count).max()
@@ -32,11 +32,18 @@ extension MAS {
 					"""
 					No installed apps found
 
-					If this is unexpected, the following command line should fix it by
-					(re)creating the Spotlight index (which might take some time):
+					If this is unexpected, any of the following command lines should fix things by reindexing apps in the\
+					 Spotlight MDS index (which might take some time):
 
+					# Individual apps (if you know exactly what apps were incorrectly omitted):
+					mdimport /Applications/Example.app
+
+					# All apps (<LargeAppVolume> is the volume optionally selected for large apps):
+					mdimport /Applications /Volumes/<LargeAppVolume>/Applications
+
+					# All file system volumes (if neither aforementioned command solved the issue):
 					sudo mdutil -Eai on
-					"""
+					""",
 				)
 				return
 			}
@@ -48,10 +55,10 @@ extension MAS {
 						format: format,
 						installedApp.adamID,
 						installedApp.name.padding(toLength: maxNameLength, withPad: " ", startingAt: 0),
-						installedApp.version
+						installedApp.version,
 					)
 				}
-				.joined(separator: "\n")
+				.joined(separator: "\n"),
 			)
 		}
 	}
