@@ -18,7 +18,7 @@ extension MAS {
 		static let configuration = CommandConfiguration(
 			abstract: "Install the first app returned from searching the App Store",
 			discussion: // swiftformat:disable:next indent
-				"App will install only if it has already been gotten\n\n\(requiresRootPrivilegesMessage(to: "install"))"
+				"App will install only if it has already been gotten\n\n\(requiresRootPrivilegesMessage(to: "install"))",
 		)
 
 		@OptionGroup
@@ -27,12 +27,15 @@ extension MAS {
 		private var searchTermOptionGroup: SearchTermOptionGroup
 
 		func run() async throws {
-			try await run(installedApps: try await installedApps, appCatalog: ITunesSearchAppCatalog())
+			try await run(installedApps: try await installedApps, searchForAppsMatchingSearchTerm: search(for:))
 		}
 
-		private func run(installedApps: [InstalledApp], appCatalog: some AppCatalog) async throws {
+		private func run(
+			installedApps: [InstalledApp],
+			searchForAppsMatchingSearchTerm: (String) async throws -> [CatalogApp],
+		) async throws {
 			let searchTerm = searchTermOptionGroup.searchTerm
-			guard let adamID = try await appCatalog.search(for: searchTerm).first?.adamID else {
+			guard let adamID = try await searchForAppsMatchingSearchTerm(searchTerm).first?.adamID else {
 				throw MASError.noCatalogAppsFound(for: searchTerm)
 			}
 
@@ -43,7 +46,7 @@ extension MAS {
 			try await AppStore.install.apps(
 				withADAMIDs: [adamID],
 				force: forceOptionGroup.force,
-				installedApps: installedApps
+				installedApps: installedApps,
 			)
 		}
 	}
