@@ -10,19 +10,18 @@ enum MASError: Error {
 	case noCatalogAppsFound(for: String)
 	case unknownAppID(AppID)
 	case unparsableURL(String)
-	case unsupportedCommand(String)
 
 	static func error(
 		_ message: String,
 		error: String?,
 		separator: String = ":\n",
-		separatorAndErrorReplacement: String = ""
+		separatorAndErrorReplacement: String = "",
 	) -> Self {
 		Self.error(
 			message,
 			error: error.map { Self.error($0) },
 			separator: separator,
-			separatorAndErrorReplacement: separatorAndErrorReplacement
+			separatorAndErrorReplacement: separatorAndErrorReplacement,
 		)
 	}
 }
@@ -38,11 +37,6 @@ extension MASError: CustomStringConvertible {
 			"No apps found in the App Store for \(appID)"
 		case let .unparsableURL(string):
 			"Failed to parse URL from \(string)"
-		case let .unsupportedCommand(commandName):
-			"""
-			\(commandName) is not supported on this macOS version due to changes in macOS
-			See https://github.com/mas-cli/mas#%EF%B8%8F-known-issues
-			"""
 		}
 	}
 }
