@@ -33,8 +33,8 @@ enum AppID: CustomStringConvertible, Sendable {
 }
 
 extension [AppID] { // swiftlint:disable:this file_types_order
-	func lookupCatalogApps(from appCatalog: some AppCatalog) async -> [CatalogApp] {
-		await compactMap(attemptingTo: "lookup app for") { try await appCatalog.lookup(appID: $0) }
+	func lookupCatalogApps(lookupAppFromAppID: (AppID) async throws -> CatalogApp) async -> [CatalogApp] {
+		await compactMap(attemptingTo: "lookup app for", lookupAppFromAppID)
 	}
 }
 
