@@ -71,7 +71,11 @@ struct Printer: Sendable {
 
 	func clearCurrentLine(of fileHandle: FileHandle) {
 		if fileHandle.isTerminal {
-			fileHandle.write(Data("\(csi)2K\(csi)0G".utf8))
+			do {
+				try fileHandle.write(contentsOf: Data("\(csi)2K\(csi)0G".utf8))
+			} catch {
+				// Do nothing
+			}
 		}
 	}
 
@@ -81,7 +85,7 @@ struct Printer: Sendable {
 		format: String,
 		error: (any Error)?,
 		separator: String,
-		terminator: String
+		terminator: String,
 	) {
 		guard !items.isEmpty || (error != nil && !(error is ExitCode)) else {
 			return
@@ -97,12 +101,16 @@ struct Printer: Sendable {
 				return "\(errorDescription.isEmpty ? "" : items.isEmpty ? " " : "\n")\(errorDescription)\(terminator)"
 			}
 			?? terminator, // swiftformat:disable:this indent
-			to: .standardError
+			to: .standardError,
 		)
 	}
 
 	private func print(_ items: [String], separator: String, terminator: String, to fileHandle: FileHandle) {
-		fileHandle.write(Data(items.joined(separator: separator).appending(terminator).utf8))
+		do {
+			try fileHandle.write(contentsOf: Data(items.joined(separator: separator).appending(terminator).utf8))
+		} catch {
+			// Do nothing
+		}
 	}
 
 	private func print(
@@ -111,7 +119,7 @@ struct Printer: Sendable {
 		format: String,
 		separator: String,
 		terminator: String,
-		to fileHandle: FileHandle
+		to fileHandle: FileHandle,
 	) {
 		let formattedPrefix = mas.format(prefix: prefix, format: format, for: fileHandle)
 		print(
@@ -119,7 +127,7 @@ struct Printer: Sendable {
 			?? [formattedPrefix], // swiftformat:disable:this indent
 			separator: separator,
 			terminator: terminator,
-			to: fileHandle
+			to: fileHandle,
 		)
 	}
 }
