@@ -5,16 +5,12 @@
 // Copyright © 2025 mas-cli. All rights reserved.
 //
 
-private import Foundation
-
 extension String {
 	var quoted: String {
-		"'\(replacingOccurrences(of: "'", with: "\\'"))'"
+		"'\(replacing("'", with: "\\'"))'"
 	}
-}
 
-extension String? {
-	var quoted: String {
-		map(\.quoted) ?? "unknown"
+	func removingSuffix(_ suffix: Self) -> Self {
+		hasSuffix(suffix) ? Self(dropLast(suffix.count)) : self
 	}
 }
