@@ -19,7 +19,7 @@ extension Data {
 	init(
 		fromResource resourcePath: String?,
 		withExtension ext: String? = "json",
-		inSubfolderPath subfolderPath: String? = ""
+		inSubfolderPath subfolderPath: String? = "",
 	) throws {
 		guard
 			let resourceURL = Bundle.module.url(forResource: resourcePath, withExtension: ext, subdirectory: subfolderPath)
@@ -30,7 +30,7 @@ extension Data {
 				\(resourcePath.map { " at \($0)" } ?? "")\
 				\(ext.map { " with extension \($0)" } ?? "")\
 				\(subfolderPath.map { " in subfolder \($0)" } ?? "")
-				"""
+				""",
 			)
 		}
 
