@@ -6,6 +6,7 @@
 //
 
 internal import Foundation
+@testable private import mas
 
 struct Consequences<Value> {
 	let value: Value?
@@ -78,8 +79,8 @@ private struct StandardStreamCapture { // swiftlint:disable:this one_declaration
 	}
 
 	private func finishAndRead(encoding: String.Encoding) -> (stdout: String, stderr: String) {
-		fflush(stdout)
-		fflush(stderr)
+		unsafe fflush(stdout)
+		unsafe fflush(stderr)
 		dup2(outDuplicateFD, outOriginalFD)
 		dup2(errDuplicateFD, errOriginalFD)
 		try? outPipe.fileHandleForWriting.close()
@@ -88,21 +89,16 @@ private struct StandardStreamCapture { // swiftlint:disable:this one_declaration
 		close(outDuplicateFD)
 		close(errDuplicateFD)
 
-		return (
-			String(data: outPipe.fileHandleForReading.readDataToEndOfFile(), encoding: encoding) ?? "",
-			String(data: errPipe.fileHandleForReading.readDataToEndOfFile(), encoding: encoding) ?? ""
-		)
-	}
+		return (try! outPipe.readToEnd(encoding: encoding) ?? "", try! errPipe.readToEnd(encoding: encoding) ?? "")
+	} // swiftlint:disable:previous force_try
 }
 
 enum NoValue: Equatable { // swiftlint:disable:this one_declaration_per_file
 	// Empty
 }
 
-func consequencesOf(
-	encoding: String.Encoding = .utf8,
-	_ body: @autoclosure () throws -> Void
-) -> Consequences<NoValue> {
+func consequencesOf(encoding: String.Encoding = .utf8, _ body: @autoclosure () throws -> Void)
+-> Consequences<NoValue> { // swiftformat:disable:this indent
 	let capture = StandardStreamCapture(encoding: encoding)
 	do {
 		return capture.consequences(value: try body())
@@ -111,10 +107,8 @@ func consequencesOf(
 	}
 }
 
-func consequencesOf(
-	encoding: String.Encoding = .utf8,
-	_ body: @autoclosure () async throws -> Void
-) async -> Consequences<NoValue> {
+func consequencesOf(encoding: String.Encoding = .utf8, _ body: @autoclosure () async throws -> Void)
+async -> Consequences<NoValue> { // swiftformat:disable:this indent
 	let capture = StandardStreamCapture(encoding: encoding)
 	do {
 		return capture.consequences(value: try await body())
@@ -123,10 +117,8 @@ func consequencesOf(
 	}
 }
 
-func consequencesOf<Value>(
-	encoding: String.Encoding = .utf8,
-	_ body: @autoclosure () throws -> Value?
-) -> Consequences<Value> {
+func consequencesOf<Value>(encoding: String.Encoding = .utf8, _ body: @autoclosure () throws -> Value?)
+-> Consequences<Value> { // swiftformat:disable:this indent
 	let capture = StandardStreamCapture(encoding: encoding)
 	do {
 		return capture.consequences(value: try body())
@@ -135,10 +127,8 @@ func consequencesOf<Value>(
 	}
 }
 
-func consequencesOf<Value>(
-	encoding: String.Encoding = .utf8,
-	_ body: @autoclosure () async throws -> Value?
-) async -> Consequences<Value> {
+func consequencesOf<Value>(encoding: String.Encoding = .utf8, _ body: @autoclosure () async throws -> Value?)
+async -> Consequences<Value> { // swiftformat:disable:this indent
 	let capture = StandardStreamCapture(encoding: encoding)
 	do {
 		return capture.consequences(value: try await body())
